  <tr>
    <td>{{ object.get_link }}</td>
    <td>{{ object.slug }}</td>
    <td>{{ object.created }}</td>
    <td>{{ object.updated }}</td>
    <td>{{ object.get_year_in_school_display }}</td>
    <td>{{ object.tests }}</td>
    <td>{{ object.moment }}</td>
    <td><a href="{% url 'testapp:testmodel-del' object.slug %}">delete</a></td>
  </tr>
