# Generated by Django 2.0.3 on 2018-03-26 00:00

from django.db import migrations, models
import ndh.models


class Migration(migrations.Migration):

    dependencies = [
        ('testapp', '0002_testmodellist'),
    ]

    operations = [
        migrations.CreateModel(
            name='TestModelPK',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
            bases=(ndh.models.Links, models.Model),
        ),
    ]
