{% extends 'base.html' %}

{% block content %}
<h1>{{ object }}</h1>

<table class="table">

  <tr>
    <th>Name</th>
    <th>Slug</th>
    <th>Created</th>
    <th>Updated</th>
    <th>Year in School</th>
    <th>Tests</th>
    <th>Moment</th>
    <th>Delete</th>
  </tr>
  {% include 'testapp/testmodel.html' with object=object %}
</table>
{% endblock %}
