{% extends 'ndh.html' %}
{% load ndh %}

{% block pagetitle %}Test Page Title{% endblock %}
{% block sitetitle %}Test Site Title{% endblock %}
{% block navbarleft %}
{% navbar_item 'testapp:testmodels' 'List' %}
{% navbar_item 'testapp:testmodel-add' 'Create' %}
{% endblock %}

{% block content %}
{% show_email email %}
{% endblock %}
