{% extends 'base.html' %}

{% block content %}
<h1>Mot de passe changé !</h1>
<p>Ton mot de passe a bien été changé. Tu devrais pouvoir <a href="{% url 'login' %}">te logger</a> maintenant.</p>
{% endblock %}
